@@ -31,6 +31,7 @@ import (
 
 	imagepullerv1alpha1 "github.com/che-incubator/kubernetes-image-puller-operator/api/v1alpha1"
 	devfile "github.com/devfile/api/v2/pkg/apis/workspaces/v1alpha2"
+	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
@@ -73,6 +74,13 @@ type CheClusterSpec struct {
 // Development environment configuration.
 // +k8s:openapi-gen=true
 type CheClusterDevEnvironments struct {
+	//
+	// GatewayContainer configuration.
+	// +optional
+	GatewayContainer *Container `json:"gatewayContainer,omitempty"`
+	// Project clone container configuration.
+	// +optional
+	ProjectCloneContainer *Container `json:"projectCloneContainer,omitempty"`
 	// Workspaces persistent storage.
 	// +optional
 	// +kubebuilder:default:={pvcStrategy: per-user}
@@ -137,6 +145,15 @@ type CheClusterDevEnvironments struct {
 	// +kubebuilder:validation:Minimum:=1
 	// +kubebuilder:default:=300
 	StartTimeoutSeconds *int32 `json:"startTimeoutSeconds,omitempty"`
+	// DeploymentStrategy defines the deployment strategy to use to replace existing workspace pods
+	// with new ones. The available deployment stragies are `Recreate` and `RollingUpdate`.
+	// With the `Recreate` deployment strategy, the existing workspace pod is killed before the new one is created.
+	// With the `RollingUpdate` deployment strategy, a new workspace pod is created and the existing workspace pod is deleted
+	// only when the new workspace pod is in a ready state.
+	// If not specified, the default `Recreate` deployment strategy is used.
+	// +optional
+	// +kubebuilder:validation:Enum=Recreate;RollingUpdate
+	DeploymentStrategy appsv1.DeploymentStrategyType `json:"deploymentStrategy,omitempty"`
 	// Total number of workspaces, both stopped and running, that a user can keep.
 	// The value, -1, allows users to keep an unlimited number of workspaces.
 	// +kubebuilder:validation:Minimum:=-1
@@ -148,6 +165,9 @@ type CheClusterDevEnvironments struct {
 	// +kubebuilder:validation:Minimum:=-1
 	// +optional
 	MaxNumberOfRunningWorkspacesPerUser *int64 `json:"maxNumberOfRunningWorkspacesPerUser,omitempty"`
+	// User configuration.
+	// +optional
+	User *UserConfiguration `json:"user,omitempty"`
 }
 
 // Che components configuration.
@@ -211,6 +231,10 @@ type CheClusterSpecNetworking struct {
 	// The secret must have a `app.kubernetes.io/part-of=che.eclipse.org` label.
 	// +optional
 	TlsSecretName string `json:"tlsSecretName,omitempty"`
+	// IngressClassName is the name of an IngressClass cluster resource.
+	// If a class name is defined in both the `IngressClassName` field and the `kubernetes.io/ingress.class` annotation,
+	// `IngressClassName` field takes precedence.
+	IngressClassName string `json:"ingressClassName,omitempty"`
 	// Authentication settings.
 	// +optional
 	// +kubebuilder:default:={gateway: {configLabels: {app: che, component: che-gateway-config}}}
@@ -246,13 +270,13 @@ type CheServer struct {
 	// +optional
 	// +kubebuilder:default:=false
 	Debug *bool `json:"debug,omitempty"`
-	// ClusterRoles assigned to Che ServiceAccount.
-	// The defaults roles are:
-	// - `<che-namespace>-cheworkspaces-namespaces-clusterrole`
-	// - `<che-namespace>-cheworkspaces-clusterrole`
-	// - `<che-namespace>-cheworkspaces-devworkspace-clusterrole`
-	// where the <che-namespace> is the namespace where the CheCluster CRD is created.
+	// Additional ClusterRoles assigned to Che ServiceAccount.
 	// Each role must have a `app.kubernetes.io/part-of=che.eclipse.org` label.
+	// The defaults roles are:
+	// - `<che-namespace>-cheworkspaces-clusterrole`
+	// - `<che-namespace>-cheworkspaces-namespaces-clusterrole`
+	// - `<che-namespace>-cheworkspaces-devworkspace-clusterrole`
+	// where the <che-namespace> is the namespace where the CheCluster CR is created.
 	// The Che Operator must already have all permissions in these ClusterRoles to grant them.
 	// +optional
 	ClusterRoles []string `json:"clusterRoles,omitempty"`
@@ -411,6 +435,13 @@ type TrustedCerts struct {
 	GitTrustedCertsConfigMapName string `json:"gitTrustedCertsConfigMapName,omitempty"`
 }
 
+type UserConfiguration struct {
+	// Additional ClusterRoles assigned to the user.
+	// The role must have `app.kubernetes.io/part-of=che.eclipse.org` label.
+	// +optional
+	ClusterRoles []string `json:"clusterRoles,omitempty"`
+}
+
 // Configuration settings related to the workspaces persistent storage.
 type WorkspaceStorage struct {
 	// PVC settings when using the `per-user` PVC strategy.
@@ -796,7 +827,7 @@ type CheCluster struct {
 	Status CheClusterStatus `json:"status,omitempty"`
 }
 
-//+kubebuilder:object:root=true
+// +kubebuilder:object:root=true
 // The CheClusterList contains a list of CheClusters.
 type CheClusterList struct {
 	metav1.TypeMeta `json:",inline"`
